@@ -148,12 +148,12 @@ def write_to_file(file, data) -> bool:
     return True
 
 
-def system_info() -> bool:
+def system_info() -> None:
     """Create a markdown table of various system information."""
     # Project
     from hyperglass.util.system_info import get_system_info
 
-    values = get_system_info()
+    data = get_system_info()
 
     def _code(val):
         return f"`{str(val)}`"
@@ -161,39 +161,21 @@ def system_info() -> bool:
     def _bold(val):
         return f"**{str(val)}**"
 
-    def _suffix(val, suffix):
-        return f"{str(val)}{str(suffix)}"
+    md_table_lines = ("| Metric | Value |", "| :----- | :---- |")
 
-    columns = (
-        ("hyperglass Version", _bold),
-        ("hyperglass Path", _code),
-        ("Python Version", _code),
-        ("Platform Info", _code),
-        ("CPU Info", None),
-        ("Logical Cores", _code),
-        ("Physical Cores", _code),
-        ("Processor Speed", "GHz"),
-        ("Total Memory", " GB"),
-        ("Memory Utilization", "%"),
-        ("Total Disk Space", " GB"),
-        ("Disk Utilization", "%"),
-    )
-    md_table_lines = ("| Metric | Value |", "| ------ | ----- |")
+    for title, metric in data.items():
+        value, mod = metric
 
-    for i, metric in enumerate(values):
-        title, mod = columns[i]
-        value = metric
+        title = _bold(title)
 
-        if isinstance(mod, str):
-            value = _suffix(value, mod)
-        elif callable(mod):
-            value = mod(value)
+        if mod == "code":
+            value = _code(value)
 
-        md_table_lines += (f"| **{title}** | {value} |",)
+        md_table_lines += (f"| {title} | {value} |",)
 
     md_table = "\n".join(md_table_lines)
 
     info("Please copy & paste this table in your bug report:\n")
     echo(md_table + "\n")
 
-    return True
+    return None
